==> octave-6.1.0.tar.gz: octave-6.1.0/libinterp/corefcn/oct-procbuf.h <==
////////////////////////////////////////////////////////////////////////
//
// Copyright (C) 1996-2020 The Octave Project Developers
//
// See the file COPYRIGHT.md in the top-level directory of this
// distribution or <https://octave.org/copyright/>.
//
// This file is part of Octave.
//
// Octave is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Octave is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Octave; see the file COPYING.  If not, see
// <https://www.gnu.org/licenses/>.
//
////////////////////////////////////////////////////////////////////////

// This class is based on the procbuf class from libg++, written by
// Per Bothner, Copyright (C) 1993 Free Software Foundation.

#if ! defined (octave_oct_procbuf_h)
#define octave_oct_procbuf_h 1

#include "octave-config.h"

#include <sys/types.h>

#include "c-file-ptr-stream.h"

class
octave_procbuf : public c_file_ptr_buf
{
public:

  octave_procbuf (void)
    : c_file_ptr_buf (nullptr), wstatus (-1), open_p (false), proc_pid (-1),
      next (nullptr) { }

  octave_procbuf (const char *command, int mode)
    : c_file_ptr_buf (nullptr), wstatus (-1), open_p (false), proc_pid (-1),
      next (nullptr) { open (command, mode); }

  // No copying!

  octave_procbuf (const octave_procbuf&) = delete;

  octave_procbuf& operator = (const octave_procbuf&) = delete;

  ~octave_procbuf (void) { close (); }

  octave_procbuf * open (const char *command, int mode);

  octave_procbuf * close (void);

  int wait_status (void) const { return wstatus; }

  bool is_open (void) const { return open_p; }

  pid_t pid (void) const { return proc_pid; }

protected:

  int wstatus;

  bool open_p;

  pid_t proc_pid;

  octave_procbuf *next;
};

extern void symbols_of_oct_procbuf (void);

#endif

==> octave-9.3.0.tar.gz: octave-9.3.0/libinterp/corefcn/oct-procbuf.h <==
////////////////////////////////////////////////////////////////////////
//
// Copyright (C) 1996-2024 The Octave Project Developers
//
// See the file COPYRIGHT.md in the top-level directory of this
// distribution or <https://octave.org/copyright/>.
//
// This file is part of Octave.
//
// Octave is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Octave is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Octave; see the file COPYING.  If not, see
// <https://www.gnu.org/licenses/>.
//
////////////////////////////////////////////////////////////////////////

// This class is based on the procbuf class from libg++, written by
// Per Bothner, Copyright (C) 1993 Free Software Foundation.

#if ! defined (octave_oct_procbuf_h)
#define octave_oct_procbuf_h 1

#include "octave-config.h"

#include <sys/types.h>

#include "c-file-ptr-stream.h"

OCTAVE_BEGIN_NAMESPACE(octave)

class
procbuf : public c_file_ptr_buf
{
public:

  procbuf ()
    : c_file_ptr_buf (nullptr), m_wstatus (-1), m_open_p (false),
      m_proc_pid (-1), m_next (nullptr)
  { }

  procbuf (const char *command, int mode)
    : c_file_ptr_buf (nullptr), m_wstatus (-1), m_open_p (false),
      m_proc_pid (-1), m_next (nullptr)
  { open (command, mode); }

  OCTAVE_DISABLE_COPY_MOVE (procbuf)

  ~procbuf () { close (); }

  procbuf * open (const char *command, int mode);

  procbuf * close ();

  int wait_status () const { return m_wstatus; }

  bool is_open () const { return m_open_p; }

  pid_t pid () const { return m_proc_pid; }

protected:

  int m_wstatus;

  bool m_open_p;

  pid_t m_proc_pid;

  procbuf *m_next;
};

OCTAVE_END_NAMESPACE(octave)

#endif
